@@ -84,6 +84,11 @@ public class HistorySet implements Serializable {
 		return newNo( (int)new Date().getTime() & 0x7fffffff );
 	}
 
+	synchronized void forceNewNo( int no ) {
+		if ( hist.get( no ) != null )	return;
+		newNo( no );
+	}
+
 	synchronized int toInt( String name, int org ) {
 		if ( name == null )	return org;
 		if ( name.isEmpty() )	return org;
