@@ -429,7 +429,11 @@ public abstract class Supervisor extends HttpServlet {
 			if ( ajax != null || ukey != null ) {
 				String	call_key = ( ajax != null )?	ajax.getValue( 0 ):	ukey.getValue( 0 );
 				Option.trace( "call_key=%s", call_key );
-				Page	sub = data.hist.get( (path_data.from_histry != null)? path_data.from_histry: HistorySet.ROOT ).getBrowsingPage( call_key );
+				Page	sub = null;
+				History	history = data.hist.get( (path_data.from_histry != null)? path_data.from_histry: HistorySet.ROOT );
+				if ( history != null ) {
+					sub = history.getBrowsingPage( call_key );
+				}
 				if ( sub != null ) {
 					fact.returnPage( last_page );
 					last_page = sub;
@@ -459,7 +463,11 @@ public abstract class Supervisor extends HttpServlet {
 					return;
 				}
 				if ( last_page.isAllowHistoryAdd() ) {
-					Page	sub = data.hist.get( (path_data.from_histry != null)? path_data.from_histry: HistorySet.ROOT ).getPage( last_page.getID() );
+					Page	sub = null;
+					History	history = data.hist.get( (path_data.from_histry != null)? path_data.from_histry: HistorySet.ROOT );
+					if ( history != null ) {
+						sub = history.getPage( last_page.getID() );
+					}
 					if ( sub != null ) {
 						fact.returnPage( last_page );
 						last_page = sub;
@@ -722,6 +730,7 @@ public abstract class Supervisor extends HttpServlet {
 					if ( date.compareTo( new HTTPDate( mod[0] ) ) <= 0 ) {
 						res.setStatus( 304 );
 						res.setContentType( mime );
+						data.hist.forceNewNo( next_page.getHistoryKey() );
 						data.hist.get( next_page.getHistoryKey() ).add( next_page );
 						return;
 					}
@@ -763,7 +772,6 @@ public abstract class Supervisor extends HttpServlet {
 				w.writeTo( res );
 			}
 		}
-		//data.hist.get( next_page.getHistoryKey() ).add( next_page );
 	}
 
 	private boolean gzip( RequestParameter param, HttpServletRequest req, HttpServletResponse res, Page page, SessionData data, String mime )  throws Exception {
