@@ -70,34 +70,44 @@ public class Anchor extends Tag implements PageHooker, Clickable {
 	}
 
 	public void afterOutput( Page from, Page to, RequestParameter req ) throws Exception {
-		String	id = makeID();
-		StringBuilder	buf = new StringBuilder( "function(ev){" );
-		buf = buf.append( "if(!paraselene_agency_a(paraselene_get_id('" );
-		buf = buf.append( id );
-		buf = buf.append( "'),'" );
-		buf = buf.append( getAssignedPage().getUniqueKey() );
-		buf = buf.append( "'))paraselene_kill_event(ev);}" );
-		setAnonymousEventHandler( "click", buf.toString() );
+		commitDaemon();
 
 		Attribute	href = getAttribute( "href" );
 		if ( href == null )	return;
-		if ( req.getSupervisor().isMyHostURI( href.getString() ) ) {
+		String	url = href.getString();
+		if ( req.getSupervisor().isMyHostURI( url ) && url.charAt( 0 ) != '/' ) {
 			URIValue	uv = (URIValue)href.get();
 			QueryItem[]	item = uv.getQuery();
 			ArrayList<QueryItem>	list = new ArrayList<QueryItem>();
+			boolean	flag = false;
 			for ( int i = 0; i < item.length; i++ ) {
-				if ( Form.PAGE_UKEY.equals( item[i].getName() ) )	return;
+				if ( Form.PAGE_UKEY.equals( item[i].getName() ) ||
+					ANCHOR_ID.equals( item[i].getName() ) ||
+					ANCHOR_URL_ID.equals( item[i].getName() )
+				) {
+					if ( !isClicked() )	continue;
+				}
 				list.add( item[i] );
 			}
 			list.add( new QueryItem( Form.PAGE_UKEY, getAssignedPage().getUniqueKey() ) );
 			if ( !fix_id_f ) {
 				list.add( new QueryItem( ANCHOR_URL_ID, make_id() ) );
 			}
-			list.add( new QueryItem( ANCHOR_ID, id ) );
+			list.add( new QueryItem( ANCHOR_ID, makeID() ) );
 			uv.setQuery( list.toArray( new QueryItem[0] ) );
 		}
 	}
 
+	public void commitDaemon() {
+		StringBuilder	buf = new StringBuilder( "function(ev){" );
+		buf = buf.append( "if(!paraselene_agency_a(paraselene_get_id('" );
+		buf = buf.append( makeID() );
+		buf = buf.append( "'),'" );
+		buf = buf.append( getAssignedPage().getUniqueKey() );
+		buf = buf.append( "'))paraselene_kill_event(ev);}" );
+		setAnonymousEventHandler( "click", buf.toString() );
+	}
+
 	private boolean	pushed = false;
 	private Object	obj = null;
 
